pub struct AdapterDescriptor {
pub pack_id: String,
pub pack_version: String,
pub name: String,
pub kind: MessagingAdapterKind,
pub component: String,
pub default_flow: Option<String>,
pub custom_flow: Option<String>,
pub capabilities: Option<MessagingAdapterCapabilities>,
pub source: Option<PathBuf>,
}Fields
pack_id: Stringpack_version: Stringname: Stringkind: MessagingAdapterKindcomponent: Stringdefault_flow: Option<String>custom_flow: Option<String>capabilities: Option<MessagingAdapterCapabilities>source: Option<PathBuf>Implementations
Sourceimpl AdapterDescriptor
impl AdapterDescriptor
Sourcepub fn allows_ingress(&self) -> bool
pub fn allows_ingress(&self) -> bool
Returns true if the adapter can be used for ingress.
Sourcepub fn allows_egress(&self) -> bool
pub fn allows_egress(&self) -> bool
Returns true if the adapter can be used for egress.