pub struct EventToMessageBridge { /* private fields */ }Expand description
Auto-generated bindings for an instance a component which
implements the world event-to-message-bridge.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
EventToMessageBridge::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
EventToMessageBridgePreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesEventToMessageBridgePre::instantiateto create aEventToMessageBridge. -
If you’ve instantiated the instance yourself already then you can use
EventToMessageBridge::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl EventToMessageBridge
impl EventToMessageBridge
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<EventToMessageBridge, Error>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<EventToMessageBridge, Error>
Convenience wrapper around EventToMessageBridgePre::new and
EventToMessageBridgePre::instantiate.
Sourcepub fn new(
store: impl AsContextMut,
instance: &Instance,
) -> Result<EventToMessageBridge, Error>
pub fn new( store: impl AsContextMut, instance: &Instance, ) -> Result<EventToMessageBridge, Error>
Convenience wrapper around EventToMessageBridgeIndices::new and
EventToMessageBridgeIndices::load.
pub fn add_to_linker<T, D>(
linker: &mut Linker<T>,
host_getter: fn(&mut T) -> <D as HasData>::Data<'_>,
) -> Result<(), Error>where
D: HostWithStore + HostWithStore + HostWithStore,
<D as HasData>::Data<'a>: for<'a> Host + for<'a> Host + for<'a> Host,
T: 'static,
pub fn greentic_events_bridge_bridge_api(&self) -> &Guest