pub struct MessageToEventBridge { /* private fields */ }Expand description
Auto-generated bindings for an instance a component which
implements the world message-to-event-bridge.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
MessageToEventBridge::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
MessageToEventBridgePreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesMessageToEventBridgePre::instantiateto create aMessageToEventBridge. -
If you’ve instantiated the instance yourself already then you can use
MessageToEventBridge::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl MessageToEventBridge
impl MessageToEventBridge
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<MessageToEventBridge, Error>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<MessageToEventBridge, Error>
Convenience wrapper around MessageToEventBridgePre::new and
MessageToEventBridgePre::instantiate.
Sourcepub fn new(
store: impl AsContextMut,
instance: &Instance,
) -> Result<MessageToEventBridge, Error>
pub fn new( store: impl AsContextMut, instance: &Instance, ) -> Result<MessageToEventBridge, Error>
Convenience wrapper around MessageToEventBridgeIndices::new and
MessageToEventBridgeIndices::load.
pub fn add_to_linker<T, D>(
linker: &mut Linker<T>,
host_getter: fn(&mut T) -> <D as HasData>::Data<'_>,
) -> Result<(), Error>where
D: HostWithStore + HostWithStore + HostWithStore,
<D as HasData>::Data<'a>: for<'a> Host + for<'a> Host + for<'a> Host,
T: 'static,
pub fn greentic_events_bridge_bridge_api(&self) -> &Guest