pub struct Source { /* private fields */ }Expand description
Auto-generated bindings for an instance a component which
implements the world source.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
Source::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
SourcePreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesSourcePre::instantiateto create aSource. -
If you’ve instantiated the instance yourself already then you can use
Source::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl Source
impl Source
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<Source, Error>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<Source, Error>
Convenience wrapper around SourcePre::new and
SourcePre::instantiate.
Sourcepub fn new(
store: impl AsContextMut,
instance: &Instance,
) -> Result<Source, Error>
pub fn new( store: impl AsContextMut, instance: &Instance, ) -> Result<Source, Error>
Convenience wrapper around SourceIndices::new and
SourceIndices::load.
pub fn add_to_linker<T, D>(
linker: &mut Linker<T>,
host_getter: fn(&mut T) -> <D as HasData>::Data<'_>,
) -> Result<(), Error>where
D: HostWithStore + HostWithStore,
<D as HasData>::Data<'a>: for<'a> Host + for<'a> Host,
T: 'static,
pub fn greentic_events_source_api(&self) -> &Guest