Module http

Module http 

Stable alias for HTTP client imports.

Modules

greentic

Structs

Client
Auto-generated bindings for an instance a component which implements the world client.
ClientIndices
Auto-generated bindings for index of the exports of client.
ClientPre
Auto-generated bindings for a pre-instantiated version of a component which implements the world client.

Constants

PACKAGE_ID