Module http_client

Module http_client 

v1 host capability contracts.

Modules

greentic
v1_1
greentic:http/client@1.1.0 bindings with request options + tenant context.

Structs

Client
Auto-generated bindings for an instance a component which implements the world client.
ClientIndices
Auto-generated bindings for index of the exports of client.
ClientPre
Auto-generated bindings for a pre-instantiated version of a component which implements the world client.

Constants

PACKAGE_ID