pub fn validate_reply_input(input: &ReplyInput) -> ValidationResult<()>Expand description
Validates reply input, ensuring the reply target is present.
pub fn validate_reply_input(input: &ReplyInput) -> ValidationResult<()>Validates reply input, ensuring the reply target is present.