pub struct Client {}Expand description
Auto-generated bindings for an instance a component which
implements the world client.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
Client::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
ClientPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesClientPre::instantiateto create aClient. -
If you’ve instantiated the instance yourself already then you can use
Client::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl Client
impl Client
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<Client, Error>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<Client, Error>
Convenience wrapper around ClientPre::new and
ClientPre::instantiate.
Sourcepub fn new(
store: impl AsContextMut,
instance: &Instance,
) -> Result<Client, Error>
pub fn new( store: impl AsContextMut, instance: &Instance, ) -> Result<Client, Error>
Convenience wrapper around ClientIndices::new and
ClientIndices::load.
pub fn add_to_linker<T, D>(
linker: &mut Linker<T>,
host_getter: fn(&mut T) -> <D as HasData>::Data<'_>,
) -> Result<(), Error>where
D: HostWithStore + HostWithStore,
<D as HasData>::Data<'a>: for<'a> Host + for<'a> Host,
T: 'static,