pub trait RunnerClient: Send + Sync {
// Required method
fn invoke_adapter<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
out: &'life1 OutMessage,
adapter: &'life2 AdapterDescriptor,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
}Expand description
Abstraction for invoking adapter components via an external runner.
Implementations can use HTTP, NATS, or any other transport; this crate does not assume a concrete runner dependency.